# Packages

## Information Gathering

- [sqlmap](https://github.com/sqlmapproject/sqlmap)
  Automatic SQL injection and database takeover tool
- [Striker](https://github.com/s0md3v/Striker)
  Recon & Vulnerability Scanning Suite
- [Sublist3r](https://github.com/aboul3la/Sublist3r)
  Fast subdomains enumeration tool for penetration testers
- [sherlock](https://github.com/sherlock-project/sherlock)
  Hunt down social media accounts by username across social networks
- [S3Scanner](https://github.com/sa7mon/S3Scanner)
  A tool to find open S3 buckets and dump their contents
- [gitGraber](https://github.com/hisxo/gitGraber)
  Search and find sensitive data in real time for GitHub
- [HydraRecon](https://github.com/aufzayed/HydraRecon)
  Simple recon tool

## Networking

- [nmap](https://github.com/nmap/nmap)
  the Network Mapper
- [bettercap](https://github.com/bettercap/bettercap)
  Swiss army knife for network attacks and monitoring

## Web Apps

- [XSStrike](https://github.com/s0md3v/XSStrike)
  Advanced XSS Detection Suite
- [Photon](https://github.com/s0md3v/Photon)
  Incredibly fast crawler designed for OSINT

## Passwords

- [cupp](https://github.com/Mebus/cupp)
  Common User Passwords Profiler
- [Cr3d0v3r](https://github.com/D4Vinci/Cr3d0v3r)
  Your best friend in credential reuse attacks
- [Hash-Buster](https://github.com/s0md3v/Hash-Buster)
  Why crack hashes when you can bust them?
- [changeme](https://github.com/ztgrace/changeme)
  A default credential scanner

## Obfuscation

- [Cuteit](https://github.com/D4Vinci/Cuteit)
  IP obfuscator made to make a malicious ip a bit cuter
